==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/mail.php <==
<?php

require_once('inc/phpmailer/class.phpmailer.php');
require_once('inc/smime.php');

/**
  @class Mail
  @brief Class for composing and sending emails.
  @author Martin Zlomek
  @date 01-03-2006
 */
class Mail extends PHPMailer {
	/**
	  @brief Create a new email.
	 */
	public function __construct($charSet = 'UTF-8',$bRelay = false)
	{
		$this->PluginDir = 'inc/phpmailer/';
		parent::IsSMTP();

    $this->Host = $_SESSION['HOST']?$_SESSION['HOST']:'localhost';
		$this->Port = $_SESSION['PORT']?$_SESSION['PORT']:25;
		
		//Default values
		parent::SetLanguage('en', $this->PluginDir . 'language/');
		parent::SetRelay($bRelay);
		
		$this->charSet  = $charSet;
		$this->Encoding = '8bit';
		$this->XMailer  = 'IceWarp Mailer ' . WM_VERSION;
	}

	/**
	  @brief Set the From email address and name.
	  @param $address The address.
	  @param $name The name.
	  @param $setSender If true, the Sender will be set
	 */
	public function setFrom($address, $name = '', $setSender = true)
	{
		$this->From	 = $address;
		$this->FromName = $name;

		if ($setSender) {
			$this->Sender = $address;
		}
	}

	/**
	  @brief Add the To email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addTo($address, $name = '')
	{
		parent::AddAddress($address, $name);
	}

	/**
	  @brief Add the CC email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addCC($address, $name = '')
	{
		parent::AddCC($address, $name);
	}

	/**
	  @brief Add the BCC email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addBCC($address, $name = '')
	{
		parent::AddBCC($address, $name);
	}

	/**
	  @brief Add the Replay-To email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addReplyTo($address, $name = '')
	{
		parent::AddReplyTo($address, $name);
	}

	/**
	  @brief Set the Subject of the message.
	  @param $subject The subject.
	 */
	public function setSubject($subject)
	{
		$this->Subject = $subject;
	}

	/**
	  @brief Set the Body of the message.
	  @param $text The text-only body.
	  @param $html The HTML body.
	 */
	public function setBody($text, $html = '')
	{
		if ($html != '') {
			parent::IsHTML(true);
			$this->Body	= $html;
			$this->AltBody = $text;
		} else {
			parent::IsHTML(false);
			$this->Body = $text;
		}
    
    //Bare LF FIX
      $this->Body = str_replace("\r","",$this->Body);
      $this->Body = str_replace("\n","\r\n",$this->Body); 
  }

	/**
	  @brief Add an attachment.
	  @param $file Name of the attachment file.
	  @param $type Mime type of the attachment.
	  @param $name Name of the attachment.
	 */
	public function addAttachment($file, $type, $name = '')
	{

		if (!is_file($file))
			throw new Exc('File not found');

		parent::AddAttachment($file, $name, 'base64', $type);
	}

	/**
	  @brief Add an embeded attachment.
	  @param $file Name of the attachment file.
	  @param $type Mime type of the attachment.
	  @param $cid Content ID of the attachment (e.g. <img src="cid:1"/>).
	  @param $name Name of the attachment.
	 */
	public function addEmbededAttachment($file, $type, $cid, $name = '')
	{
		if (!is_file($file))
			throw new Exception('File not found');

		parent::AddEmbeddedImage($file, $cid, $name, 'base64', $type);
	}

	/**
	  @brief Add an user defined header.
	  @param The header.
	 */
	public function addHeader($header)
	{
		parent::AddCustomHeader($header);
	}

	/**
	  @brief Set the priority of the message.
	  @param $priority The priority ('high', 'normal', 'low').
	 */
	public function setPriority($priority)
	{
		switch ($priority) {
		case 'high':
			$this->Priority = 1;
			break;
		case 'normal':
			$this->Priority = 3;
			break;
		case 'low':
			$this->Priority = 5;
			break;
		}
	}

	/**
	  @brief Get message of the email.
	  @return The message.
	 */
	public function getMessage($charset='UTF-8')
	{
		$this->charSet  = $charset;

		if(!empty($this->AltBody))
			$this->ContentType = "multipart/alternative";
		$this->SetMessageType();

		return $this->CreateHeader() . $this->CreateBody();
	}

	/**
	  @brief Send the message.
	  @return False if the message has not been sent successfully.
	  Use errmsg() method to get description of the error.
	 */
	public function send($header = false,$body = false,$charset = 'UTF-8')
	{
		return @parent::Send($header,$body,$charset,$this->bRelay);
	}
	
	/**
	  @brief Set the message for encryption.
	 */
	public function encrypt()
	{
		$this->EncryptMessage = true;
	}

	/**
	  @brief Set the message for signing.
	 */
	public function sign()
	{
		$this->SignMessage = true;
	}
	
	/**
	  @brief Encrypt and/or sign the message.
	  @param $message The message.
	 */
	public function encryptAndSign(&$message)
	{
		// get first recipient of the message (that is used for encryption)
		if (isset($this->to[0][0]))
			$recipient = $this->to[0][0];
		else if (isset($this->cc[0][0]))
			$recipient = $this->cc[0][0];
		else if (isset($this->bcc[0][0]))
			$recipient = $this->bcc[0][0];
		else
			throw new Exc('No recipeint specified');
			
		SMime::processMessage($message, $recipient, $this->SignMessage,
													$this->EncryptMessage);
	}

	/**
	  @brief Get the most recent mailer error message.
	  @return The error message.
	 */
	public function errmsg()
	{
		return $this->ErrorInfo;
	}
}

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/mail.php <==
<?php

require_once('inc/phpmailer/class.phpmailer.php');
require_once('inc/smime.php');

/**
  @class Mail
  @brief Class for composing and sending emails.
  @author Martin Zlomek
  @date 01-03-2006
 */
class Mail extends PHPMailer {
	/**
	  @brief Create a new email.
	 */
	public function __construct($charSet = 'UTF-8',$bRelay = false,$bAllowEmptyReceipient = false,$sHostName = false)
	{
		$this->PluginDir = 'inc/phpmailer/';
		parent::IsSMTP();

    $this->Host = $_SESSION['HOST']?$_SESSION['HOST']:'127.0.0.1';
		$this->Hostname = $_SESSION['DOMAIN']?$_SESSION['DOMAIN']:($sHostName===false?$SERVER['SERVER_NAME']:$sHostName);
		$this->Port = $_SESSION['PORT']?$_SESSION['PORT']:25;
		
		//Default values
		parent::SetLanguage('en', $this->PluginDir . 'language/');
		parent::SetRelay($bRelay);

    $this->bRelay = $bRelay;
    $this->bAllowEmptyReceipient = $bAllowEmptyReceipient;

		$this->charSet  = $charSet?$charSet:$_SESSION['DEFAULTCHARSET'];
		$this->Encoding = '8bit';
		$this->XMailer  = 'IceWarp Mailer ' . $_SESSION['WM_VERSION'];
	}

	/**
	  @brief Set the From email address and name.
	  @param $address The address.
	  @param $name The name.
	  @param $setSender If true, the Sender will be set
	 */
	public function setFrom($address, $name = '', $setSender = true)
	{
		$this->From	 = $address;
		$this->FromName = $name;

		if ($setSender) {
			$this->Sender = $address;
		}
	}

	/**
	  @brief Add the To email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addTo($address, $name = '')
	{
		parent::AddAddress($address, $name);
	}

	/**
	  @brief Add the CC email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addCC($address, $name = '')
	{
		parent::AddCC($address, $name);
	}

	/**
	  @brief Add the BCC email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addBCC($address, $name = '')
	{
		parent::AddBCC($address, $name);
	}

	/**
	  @brief Add the Replay-To email address and name.
	  @param $address The address.
	  @param $name The name.
	 */
	public function addReplyTo($address, $name = '')
	{
		parent::AddReplyTo($address, $name);
	}

	/**
	  @brief Set the Subject of the message.
	  @param $subject The subject.
	 */
	public function setSubject($subject)
	{
		$this->Subject = $subject;
	}

	/**
	  @brief Set the Body of the message.
	  @param $text The text-only body.
	  @param $html The HTML body.
	 */
	public function setBody($text, $html = '')
	{
		if ($html != '') {
			parent::IsHTML(true);
			$this->Body	= $html;
			$this->AltBody = $text;
		} else {
			parent::IsHTML(false);
			$this->Body = $text;
		}
    
    //Bare LF FIX
      $this->Body = str_replace("\r","",$this->Body);
      $this->Body = str_replace("\n","\r\n",$this->Body); 
  }

	/**
	  @brief Add an attachment.
	  @param $file Name of the attachment file.
	  @param $type Mime type of the attachment.
	  @param $name Name of the attachment.
	 */
	public function addAttachment($file, $type, $name = '',$method = '')
	{

		if (!is_file($file))
			throw new Exc('attachment_file_not_found',$file);

    if($type=='message/rfc822') $encode = false;
    else $encode = true;     

		parent::AddAttachment($file, $name, 'base64', $type, $encode,$method);
	}

	/**
	  @brief Add an embeded attachment.
	  @param $file Name of the attachment file.
	  @param $type Mime type of the attachment.
	  @param $cid Content ID of the attachment (e.g. <img src="cid:1"/>).
	  @param $name Name of the attachment.
	 */
	public function addEmbededAttachment($file, $type, $cid, $name = '')
	{
		if (!is_file($file))
			throw new Exc('attachment_file_not_found',$file);

		parent::AddEmbeddedImage($file, $cid, $name, 'base64', $type);
	}

	/**
	  @brief Add an user defined header.
	  @param The header.
	 */
	public function addHeader($header)
	{
		parent::AddCustomHeader($header);
	}

	/**
	  @brief Set the priority of the message.
	  @param $priority The priority ('high', 'normal', 'low').
	 */
	public function setPriority($priority)
	{
		switch ($priority) {
		case 'high':
			$this->Priority = 1;
			break;
		case 'normal':
			$this->Priority = 3;
			break;
		case 'low':
			$this->Priority = 5;
			break;
		}
	}

	/**
	  @brief Get message of the email.
	  @return The message.
	 */
	public function getMessage($charset='UTF-8')
	{
		$this->charSet  = $charset;

		if(!empty($this->AltBody))
			$this->ContentType = "multipart/alternative";
		$this->SetMessageType();
    $tmpFile = Tools::randomFilename();
    $tmpFP = fopen($tmpFile,'wb+');
    
		$this->CreateHeader($tmpFP) . $this->CreateBody($tmpFP,$tmpFile);
	
	  fclose($tmpFP);
	  //Try to find a way how to append message from file (imap,pop3)
	  $result = file_get_contents($tmpFile);
	  unlink($tmpFile);

	  return $result;
  }
  
	/**
	  @brief Get message of the email.
	  @return The message.
	 */
	public function getMessageTempFile($charset='UTF-8')
	{
		$this->charSet  = $charset;

		if(!empty($this->AltBody))
			$this->ContentType = "multipart/alternative";
		$this->SetMessageType();
    $tmpFile = Tools::randomFilename();
    $tmpFP = fopen($tmpFile,'wb+');
    
		$this->CreateHeader($tmpFP) . $this->CreateBody($tmpFP,$tmpFile);
	
	  fclose($tmpFP);

	  return $tmpFile;
  }
	/**
	  @brief Send the message.
	  @return False if the message has not been sent successfully.
	  Use errmsg() method to get description of the error.
	 */
	public function send($header = false,$body = false,$charset = 'UTF-8',&$filename = false)
	{
		return @parent::Send($header,$body,$charset,$this->bRelay,$filename);
	}
	
	/**
	  @brief Set the message for encryption.
	 */
	public function encrypt()
	{
		$this->EncryptMessage = true;
	}

	/**
	  @brief Set the message for signing.
	 */
	public function sign()
	{
		$this->SignMessage = true;
	}
	
	/**
	  @brief Encrypt and/or sign the message.
	  @param $message The message.
	 */
	//public function encryptAndSign(&$message)
	public function encryptAndSign(&$fp,&$filename)
	{
		// get first recipient of the message (that is used for encryption)
		if (isset($this->to[0][0]))
			$recipient = $this->to[0][0];
		else if (isset($this->cc[0][0]))
			$recipient = $this->cc[0][0];
		else if (isset($this->bcc[0][0]))
			$recipient = $this->bcc[0][0];
		else
			throw new Exc('smime_no_recipient');
			
		SMime::processMessage($fp,$filename, $recipient, $this->SignMessage,
													$this->EncryptMessage);
	}

	/**
	  @brief Get the most recent mailer error message.
	  @return The error message.
	 */
	public function errmsg()
	{
		return $this->ErrorInfo;
	}
}

?>
